@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2007-2015 Christian Jaeger, copying@christianjaeger.ch
+# Copyright (c) 2007-2020 Christian Jaeger, copying@christianjaeger.ch
 #
 # This is free software, offered under either the same terms as perl 5
 # or the terms of the Artistic License version 2 or the terms of the
@@ -72,12 +72,9 @@ use Chj::xpipe;
 
 sub new_out {
     my $class=shift;
-    local $^F=0;
     my ($r,$self)=xpipe;
     bless $self,$class;
-    $self->xlaunch($r,0,@_); ## und wie gebe ich den Namen an?
-    # goto form: würd hier auch nix helfen da oben hard codiert. EBEN: ich brauch ein
-    # croak das den Ort der Herkunft anzeigen kann. à la mein DEBUG().
+    $self->xlaunch($r,0,@_)
 }
 *new_writer= *new_out;
 *new_write= *new_out;
@@ -85,10 +82,9 @@ sub new_out {
 
 sub new_in {
     my $class=shift;
-    local $^F=0;
     my ($self,$w)=xpipe;
     bless $self,$class;
-    $self->xlaunch($w,1,@_);
+    $self->xlaunch($w,1,@_)
 }
 *new_reader= *new_in;
 *new_read= *new_in;
@@ -96,19 +92,17 @@ sub new_in {
 
 sub new_combinedsender {
     my $class=shift;
-    local $^F=0;
     my ($self,$w)=xpipe;
     bless $self,$class;
-    $self->xlaunch3(undef,$w,$w,@_);
+    $self->xlaunch3(undef,$w,$w,@_)
 }
 
 sub new_combinedsender_with_stdin {
     my $class=shift;
-    local $^F=0;
     my $stdin= shift;
     my ($self,$w)=xpipe;
     bless $self,$class;
-    $self->xlaunch3($stdin,$w,$w,@_);
+    $self->xlaunch3($stdin,$w,$w,@_)
 }
 
 sub assume_with_maybe_stdin_stdout_stderr {
@@ -118,14 +112,12 @@ sub assume_with_maybe_stdin_stdout_stderr {
     my $in= shift;
     my $out= shift;
     my $err= shift;
-    local $^F=0;
     bless $self,$class;
-    $self->xlaunch3($in,$out,$err,@_);
+    $self->xlaunch3($in,$out,$err,@_)
 }
 
 sub new_err {
     my $class=shift;
-    local $^F=0;
     my ($self,$w)=xpipe;
     bless $self,$class;
     $self->xlaunch($w,2,@_);
@@ -134,19 +126,17 @@ sub new_err {
 sub new_receiver_with_stderr_to_fh {
     my $class=shift;
     my $errfh=shift;
-    local $^F=0;
     my ($r,$self)=xpipe;
     bless $self,$class;
-    $self->xlaunch3($r,undef,$errfh,@_); ## ... (vgl oben)
+    $self->xlaunch3($r,undef,$errfh,@_)
 }
 
 sub new_receiver_with_stdout_to_fh {
     my $class=shift;
     my $outfh=shift;
-    local $^F=0;
     my ($r,$self)=xpipe;
     bless $self,$class;
-    $self->xlaunch3($r,$outfh,undef,@_);
+    $self->xlaunch3($r,$outfh,undef,@_)
 }
 
 1
