@@ -30,7 +30,8 @@ L<FP::Repl::WithRepl>, L<FP::Repl::AutoTrap>
 
 =head1 NOTE
 
-This is alpha software! Read the package README.
+This is alpha software! Read the status section in the package README
+or on the L<website|http://functional-perl.org/>.
 
 =cut
 
